mangadap.par package
====================

Submodules
----------

.. toctree::
   :maxdepth: 4

   mangadap.par.absorptionindexdb
   mangadap.par.artifactdb
   mangadap.par.bandheadindexdb
   mangadap.par.emissionlinedb
   mangadap.par.emissionmomentsdb
   mangadap.par.parset
   mangadap.par.spectralfeaturedb
   mangadap.par.util

Module contents
---------------

.. automodule:: mangadap.par
   :members:
   :private-members:
   :undoc-members:
   :show-inheritance:
